#[non_exhaustive]pub enum EventValueType {
Choice(EventChoiceValue),
Text(EventTextConfiguration),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Choice(EventChoiceValue)
Indicates that the type of event will be an dropdown with predefined values.
Text(EventTextConfiguration)
This will check whether the state is the same as the user specified value in the text box.