pub struct Data { /* private fields */ }Expand description
As a plug-in developer you can augment your actions with additional data that the user has to fill in.
It uses the same structures as the native actions from Touch Portal itself.
You can use this for both static actions as dynamic actions. The user will have to specify values for the given data field within Touch Portal.
Implementations