pub struct FileDataBuilder { /* private fields */ }Expand description
Builder for FileData.
Implementations
Sourceimpl FileDataBuilder
impl FileDataBuilder
Sourcepub fn initial<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn initial<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
This is the default value the data object has.
Sourcepub fn extensions(&mut self, value: IndexSet<String>) -> &mut Self
pub fn extensions(&mut self, value: IndexSet<String>) -> &mut Self
This is a collection of extensions allowed to open.
eg: "extensions": ["*.jpg","*.png"]