pub struct LocalState { /* private fields */ }Expand description
The local states object represents the representation and visualisation within Touch Portal.
The id is the reference when used as a tag in text. The actual setting of the local states object when the event is triggered are described in the communication section.
Implementations
Sourceimpl LocalState
impl LocalState
pub fn builder() -> LocalStateBuilder