Struct TextSettingBuilder

pub struct TextSettingBuilder { /* private fields */ }
Builder for TextSetting.

Implementations

Source

impl TextSettingBuilder

pub fn max_length(&mut self, value: u32) -> &mut Self

This is the max amount of characters a text settings value can have.

pub fn is_password(&mut self, value: bool) -> &mut Self

If set, will hide the characters from the input field.

It will show dots instead. Please do know that communication between Touch Portal and the plug-in is open text. This option is made so that random people will not be able to peek at the password field. It is not secure.

pub fn read_only(&mut self, value: bool) -> &mut Self

For some settings you do not want the user to edit them but you do want to share them.

Using this switch will allow you to do so. Updating these setting values should be done with the dynamic functions.

pub fn build(&self) -> Result<TextSetting, TextSettingBuilderError>

Builds a new TextSetting.

Errors

If a required field has not been initialized.