#[non_exhaustive]pub enum DataFormat {
Text(TextData),
Number(NumberData),
Switch(SwitchData),
Choice(ChoiceData),
File(FileData),
Folder(FolderData),
Color(ColorData),
LowerBound(BoundData),
UpperBound(BoundData),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Text(TextData)
A data type that accepts a string
Number(NumberData)
A data type that accepts a number
Switch(SwitchData)
A data type that accepts a true or false value
Choice(ChoiceData)
A data type that accepts a string where a collection of strings can be chosen from
File(FileData)
A data type that represents a file which the user can pick with a file chooser
Folder(FolderData)
A data type that represents a folder which the user can pick with a folder chooser
Color(ColorData)
A data type that represents a color which the user can pick with a color chooser.
This value must be in a the format #RRGGBBAA.
LowerBound(BoundData)
A data type that represents a field for the user to specify the lower bound of the slider range.
The amount of decimals will also specify the precision. For example, if the user sets the lower bound to 1, all values will be whole numbers. If the value is set to 1.0 it will return connector values times 10, if the value is set to 1.00 it will return connector values times 100. The plug-in is responsible of dividing the value to the proper range before it is used. Connectors are only capable of sending integer data.
If UpperBound is also set, both fields will be checked for precision. The higher
precision will be used. A range between 1 and 5.0 means it will use the 5.0 for the
precision.
Only available for connectors.
Only available in API version 10 and above.
UpperBound(BoundData)
A data type that represents a field for the user to specify the upper bound of the slider range.
The amount of decimals will also specify the precision. For example, if the user sets the upper bound to 1, all values of the connector will be send as normal but will be translated to the range specified. If the value is set to 1.0 it will return connector values times 10, if the value is set to 1.00 it will return connector values times 100. The plug-in is responsible of dividing the value to the proper range before it is used. Connectors are only capable of sending integer data.
If LowerBound is also set, both fields will be checked for precision. The higher
precision will be used. A range between 1 and 5.0 means it will use the 5.0 for the
precision.
Only available for connectors.
Only available in API version 10 and above.