#[non_exhaustive]pub enum StateType {
Choice(ChoiceState),
Text(TextState),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Choice(ChoiceState)
A state where you specify a limited amount of state values the state can be.
Text(TextState)
A state that contains a free text field.
This type can be used for smart conversion as well.
#FF115599 (#AARRGGBB) can be interpreted by the plug-in visuals action as a color. The
format needs to be this or it will not be seen as a color and will not be converted.
A base64 representation of an image will also be allowed for specific actions such as the plug-in visuals action. This will read the base64 string representation and convert it to an image and show it on the button. We suggest to keep these as small as possible. Images used like this on a button are not stored and only exist temporary. This allows for a performant updating process. Allow for multiple updates per second depending on the computer used, the device used and the quality of the network.
The base64 string should only hold the base64 data. The meta data should be stripped. The format has to be a PNG. It has to be a squared image.